@@ -24,7 +24,7 @@ class LoadBalancerFactory:
         result = Queue()
         threads, databases = cls._create_databases(result)
         watch_dog=WatchDog(databases,LOAD_BALANCER['WAIT_TIME'])
-        watch_dog_thread=threading.Thread(target=watch_dog.check_databases_statuses(), args=(), daemon=True)
+        watch_dog_thread=threading.Thread(target=watch_dog.check_databases_statuses, args=(), daemon=True)
         watch_dog_thread.start()
         cud_algorithm = cls._create_cud_algorithm(databases, threads)
         r_algorithm = cls._create_r_algorithm(databases)
