@@ -23,10 +23,11 @@ class WaitWaiter(Waiter):
                 break
             except django.db.utils.OperationalError:
                 database.status.put(DatabaseStatus.DOWN.value)
+                database.is_down.aquire()
                 self.wait_for_connection(query, database)
 
     def wait_for_connection(self, query, database):
-        while database.status.get() == DatabaseStatus.DOWN.value:
+        while database.is_down.aquire():
             pass
 
 
@@ -37,4 +38,5 @@ class DontWaitWaiter(Waiter):
                 self._executor.run_query(query, database)
             except django.db.utils.OperationalError:
                 database.status.put(DatabaseStatus.DOWN.value)
+                database.is_down.aquire()
                 raise django.db.utils.OperationalError
