@@ -18,5 +18,7 @@ class WatchDog():
                     connections[database.name].connect()
                 except database.operational_error:
                     database.status.put(DatabaseStatus.DOWN.value)
+                    database.is_down.aquire()
                 else:
                     database.status.put(DatabaseStatus.RUNNING.value)
+                    database.is_down.release()
